@@ -18,9 +18,6 @@ import time
 import warnings
 import click
 import inspect
-import alacorder as alac
-from alacorder import parse
-from alacorder import write
 import PyPDF2
 from io import StringIO
 try:
@@ -416,7 +413,7 @@ def Charges(text: str):
     """
     Returns charges summary from case text -> List: [convictions, dcharges, fcharges, cerv_convictions, pardon_convictions, perm_convictions, conviction_ct, charge_ct, cerv_ct, pardon_ct, perm_ct, conv_cerv_ct, conv_pardon_ct, conv_perm_ct, charge_codes, conv_codes, allcharge, charges]
     """
-    cnum = getCaseNumber(text)
+    cnum = CaseNumber(text)
     rc = re.findall(r'(\d{3}\s{1}.{1,1000}?.{3}-.{3}-.{3}.{10,75})', text, re.MULTILINE)
     unclean = pd.DataFrame({'Raw':rc})
     unclean['FailTimeTest'] = unclean['Raw'].map(lambda x: bool(re.search(r'([0-9]{1}\:[0-9]{2})', x)))
