@@ -72,8 +72,10 @@ def Fees(conf):
         'AmtPaid': '', 'Balance': '', 'AmtHold': ''},index=[0])
 
     batches = pd.Series(np.array_split(queue, (math.ceil(max_cases / 100)+1)))
-    batchcount = batches.shape[0]
-    batchsize = batches[0].shape[0]
+    batchsize = max(pd.Series(batches).map(lambda x: x.shape[0]))
+    over_batched = batchsize - (batchsize * len(batches) - max_cases) 
+    batches[-1] = batches[-1][0:over_batched]
+    batchcount = len(batches)
     with click.progressbar(batches) as bar:
         for i, c in enumerate(bar):
             exptime = time.time()
@@ -86,9 +88,12 @@ def Fees(conf):
 
             b['CaseInfoOutputs'] = b['AllPagesText'].map(lambda x: get.CaseInfo(x))
             b['CaseNumber'] = b['CaseInfoOutputs'].map(lambda x: x[0])
-            b['FeeOutputs'] = b.index.map(lambda x: get.FeeSheet(b.loc[x].AllPagesText))
+            try:
+                b['FeeOutputs'] = b.index.map(lambda x: get.FeeSheet(str(b.loc[x].AllPagesText)))
+                feesheet = b['FeeOutputs'].map(lambda x: x[6]) 
+            except (AttributeError,IndexError):
+                pass
 
-            feesheet = b['FeeOutputs'].map(lambda x: x[6]) 
             feesheet = feesheet.dropna() # drop empty 
             fees =fees.dropna()
             feesheet = feesheet.tolist() # convert to list -> [df, df, df]
@@ -125,7 +130,10 @@ def Charges(conf):
         warnings.filterwarnings("ignore")
 
     batches = pd.Series(np.array_split(queue, (math.ceil(max_cases / 1000)+1))) # batches of 1000, write every 500
-    batchsize = max(batches.map(lambda x: x.shape[0]))
+    batchsize = max(pd.Series(batches).map(lambda x: x.shape[0]))
+    over_batched = batchsize - (batchsize * len(batches) - max_cases) 
+    batches[-1] = batches[-1][0:over_batched]
+    
 
     start_time = time.time()
     outputs = pd.DataFrame()
@@ -142,7 +150,7 @@ def Charges(conf):
 
             b['CaseInfoOutputs'] = b['AllPagesText'].map(lambda x: get.CaseInfo(x))
             b['CaseNumber'] = b['CaseInfoOutputs'].map(lambda x: x[0])
-            b['ChargesOutputs'] = b.index.map(lambda x: get.Charges(b.loc[x].AllPagesText))
+            b['ChargesOutputs'] = b.index.map(lambda x: get.Charges(str(b.loc[x].AllPagesText)))
 
             
             chargetabs = b['ChargesOutputs'].map(lambda x: x[17])
@@ -193,6 +201,8 @@ def Cases(conf):
     arch = pd.DataFrame({'Path':'','AllPagesText':'','Timestamp':''},index=[0])
     batches = np.array_split(queue, (math.ceil(max_cases / 1000) + 1))
     batchsize = max(pd.Series(batches).map(lambda x: x.shape[0]))
+    over_batched = batchsize - (batchsize * len(batches) - max_cases) 
+    batches[-1] = batches[-1][0:over_batched]
     if warn == False:
         warnings.filterwarnings("ignore")
     temp_no_write_arc = False
@@ -213,7 +223,7 @@ def Cases(conf):
             b['Sex'] = b['CaseInfoOutputs'].map(lambda x: x[5])
             b['Address'] = b['CaseInfoOutputs'].map(lambda x: x[6])
             b['Phone'] = b['CaseInfoOutputs'].map(lambda x: x[7])
-            b['ChargesOutputs'] = b.index.map(lambda x: get.Charges(b.loc[x].AllPagesText))
+            b['ChargesOutputs'] = b.index.map(lambda x: get.Charges(str(b.loc[x].AllPagesText)))
             b['Convictions'] = b['ChargesOutputs'].map(lambda x: x[0])
             b['DispositionCharges'] = b['ChargesOutputs'].map(lambda x: x[1])
             b['FilingCharges'] = b['ChargesOutputs'].map(lambda x: x[2])
@@ -230,7 +240,7 @@ def Cases(conf):
             b['PermanentConvictionCount'] = b['ChargesOutputs'].map(lambda x: x[13])
             b['ChargeCodes'] = b['ChargesOutputs'].map(lambda x: x[14])
             b['ConvictionCodes'] = b['ChargesOutputs'].map(lambda x: x[15])
-            b['FeeOutputs'] = b.index.map(lambda x: get.FeeSheet(b.loc[x].AllPagesText))
+            b['FeeOutputs'] = b.index.map(lambda x: get.FeeSheet(str(b.loc[x].AllPagesText)))
             b['TotalAmtDue'] = b['FeeOutputs'].map(lambda x: x[0])
             b['TotalBalance'] = b['FeeOutputs'].map(lambda x: x[1])
             b['PaymentToRestore'] = b['AllPagesText'].map(lambda x: get.PaymentToRestore(x))
@@ -420,6 +430,9 @@ def CaseInfo(conf):
 
     batches = pd.Series(np.array_split(queue, math.ceil(max_cases / 1000)))
     batchsize = max(pd.Series(batches).map(lambda x: x.shape[0]))
+    over_batched = batchsize - (batchsize * len(batches) - max_cases) 
+    batches[-1] = batches[-1][0:over_batched]
+    
 
     if warn == False:
         warnings.filterwarnings("ignore")
@@ -494,6 +507,9 @@ def map(conf, *args):
         warnings.filterwarnings("ignore")
     batches = pd.Series(np.array_split(queue, math.ceil(max_cases / 1000)))
     batchsize = max(pd.Series(batches).map(lambda x: x.shape[0]))
+    over_batched = batchsize - (batchsize * len(batches) - max_cases) 
+    batches[-1] = batches[-1][0:over_batched]
+    
 
     start_time = time.time()
     alloutputs = []
@@ -590,7 +606,6 @@ def log_complete(conf, start_time, output=None):
         except AttributeError:
             click.echo("Failed to launch!")
     if tablog or print_log:
-        click.clear()
         click.echo(f'''\nTASK COMPLETED: Successfully processed {max_cases} cases. Last batch completed in {elapsed:.2f} seconds ({cases_per_sec:.2f} cases/sec)''')
 def log_console(conf, *msg):
     path_in = conf['input_path']
@@ -598,6 +613,5 @@ def log_console(conf, *msg):
     arc_out = conf['archive_out']
     tablog = conf['tablog']
     max_cases = conf['count']
-    click.clear()
     if tablog:
         click.echo(msg)
